/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel
 * File:    SearchResultBuilder.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel;

import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata;
import de.fhhannover.inform.iron.mapserver.messages.SearchResult;

/**
 * A implementation of SearchResultBuilder is given to the {@link Searcher}
 * to construct a SearchResult. Director/Builder Pattern. In this case {@link Searcher}
 * is the Director. 
 * 
 * @version 0.1
 * @author aw
 */

/*
 * created: 01.05.10 aw
 * changes:
 *  01.05.10 aw -
 * 
 */
public abstract class SearchResultBuilder {

	protected SearchResult searchResult;
	
	public SearchResultBuilder(SearchResult sRes) {
		searchResult = sRes;
	}
	
	
	/**
	 * Add a Metadata object to the given identifier. This is probably only
	 * forwarded to a corresponding {@link SearchResult} implementation.
	 * 
	 * @param mc
	 * @param m
	 */
	public abstract void addMetadata(MetadataContainer mc, Metadata m);

	/**
	 * Only add a MetadataContainer. This is needed if we add a {@link Identifier}
	 * which has no Metadata attached to it.
	 * 
	 * @param mc
	 */
	public abstract void addMetadataContainer(MetadataContainer mc);

	/**
	 * Clean up the result with the given resultFilter.
	 * 
	 * Identifier and links are _not_ removed. They are also included
	 * in the result even if they do not have any metadata attached to them.
	 */
	public abstract void filter(Filter resultFilter);
	
	/**
	 * @return the constructed and possible filtered result
	 */
	public abstract SearchResult getResult();


}
