/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages
 * File:    RequestWithSessionId.java
 *
 * Copyright (C) 2010-2011 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages;

import de.fhhannover.inform.iron.mapserver.datamodel.exceptions.RequestCreationException;

/**
 * Abstract class to provide functionality for {@link Request}s containing
 * a SessionId. Most of them do.
 * 
 * @author aw
 *
 */
public abstract class RequestWithSessionId implements Request {
	
	private final String sessionId;
	
	RequestWithSessionId(String sid) throws RequestCreationException {
		if (sid == null || sid.length() == 0) {
			throw new RequestCreationException("sessionId not set");
		}
		sessionId = sid;
	}
	
	public String getSessionId() {
		return sessionId;
	}


}
